import React from "react";
import {
  SafeAreaView,
  View,
  StatusBar,
  Platform,
  ScrollView,
  Text,
  Pressable,
} from "react-native";
import { connect } from "react-redux";
import { useNavigation } from "@react-navigation/native";
import { comment } from "../../../redux/actions";
import moment from "jalali-moment";

//components
import CustomPressable from "../../../components/Pressable";
import Navbar from "../../../components/Navbar";
import Empty from "../../../components/Empty";

//style
import tw from "tailwind-rn";
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";

export const Tickets = ({ theme, getTicketList, list }) => {
  const navigation = useNavigation();

  React.useEffect(() => {
    getTicketList({ type: 2 });
  }, []);

  // const tickets = React.useMemo(() => {
  //   return [
  //     {
  //       title: "موضوع تیکت",
  //       message: "دریافت اشتباه کتاب های ارسالی از سامانه سفارشات",
  //       target: "دپارتمان فروش و بازاریابی",
  //       date: "1400/09/12",
  //       isNew: true,
  //       isAnswered: true,
  //     },
  //     {
  //       title: "موضوع تیکت",
  //       message: "دریافت اشتباه کتاب های ارسالی از سامانه سفارشات",
  //       target: "دپارتمان فروش و بازاریابی",
  //       date: "1400/09/12",
  //       isNew: false,
  //       isAnswered: false,
  //     },
  //   ];
  // }, [theme]);
  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        position: "relative",
        flex: 1,
      }}
    >
      <Navbar
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: "تیکت‌ها",
          bookmark: false,
          qr: false,
          back: true,
        }}
      />
      {list?.length ? (
        <ScrollView
          contentContainerStyle={{ paddingBottom: 100 }}
          style={tw("px-4 pt-4 flex")}
        >
          {list
            ?.filter((ticket) => ticket?.pid === null)
            ?.map((ticket, index) => (
              <Ticket
                ticket={ticket}
                key={index}
                theme={theme}
                isAnswered={list?.filter((tickett) => tickett?.pid === ticket?.id)?.length}
              />
            ))}
        </ScrollView>
      ) : (
        <Empty text="هیچ تیکتی وجود ندارد." />
      )}
      <View style={tw("w-full px-4")}>
        <CustomPressable
          title={"ارسال تیکت جدید"}
          backgroundColor={Colors.theme1.greenCF}
          color={"white"}
          border={{ color: "#196EC0", width: 0 }}
          width={"100%"}
          onPress={() => navigation.push("Ticket")}
        />
      </View>
    </SafeAreaView>
  );
};

const Ticket = ({ ticket, theme, isAnswered }) => {
  const navigation = useNavigation();
  const { title, text, isNew, date, unit, createdAt } = ticket;

  const light = React.useMemo(() => {
    return theme === "light";
  }, [theme]);

  return (
    <Pressable
      style={[
        tw("flex py-4 px-2 mb-5 rounded-md"),
        {
          borderWidth: 1,
          borderColor: isNew
            ? Colors.theme1.greenCF + (light ? "88" : "")
            : Colors.theme1.grayCC,
          backgroundColor: isNew
            ? Colors.theme1.greenCF + "11"
            : Colors.theme1.gray20 + "0a",
        },
      ]}
      onPress={() => navigation.push("TicketStatus")}
    >
      <Text
        style={{
          fontFamily: "Medium",
          fontSize: fontSize.tiny,
          color: light
            ? Colors.theme1.green79
            : isNew
            ? Colors.theme1.greenCF
            : Colors.theme1.white,
          textAlign: "left",
        }}
      >
        {moment(createdAt).format("jYYYY/jMM/jDD")}
      </Text>
      <Text
        style={{
          fontFamily: "Medium",
          textAlign: "right",
          fontSize: fontSize.lg,
          color: light
            ? Colors.theme1.green79
            : isNew
            ? Colors.theme1.greenCF
            : Colors.theme1.white,
        }}
      >
        {title}
      </Text>
      <Text
        style={{
          fontFamily: "Regular",
          textAlign: "right",
          fontSize: fontSize.lg,
          color: light
            ? Colors.theme1.green79
            : isNew
            ? Colors.theme1.greenCF
            : Colors.theme1.white,
          marginTop: 5,
        }}
      >
        {text}
      </Text>
      <View style={tw("flex flex-row-reverse justify-between mt-4")}>
        <Text
          style={{
            fontFamily: "Light",
            textAlign: "right",
            fontSize: fontSize.sm,
            color: light
              ? Colors.theme1.green79
              : isNew
              ? Colors.theme1.greenCF
              : Colors.theme1.white,
          }}
        >
          {unit}
        </Text>
        <Text
          style={{
            borderRadius: 4,
            padding: 4,
            fontFamily: "Regular",
            fontSize: fontSize.sm,
            borderWidth: 1,
            borderColor: isNew
              ? Colors.theme1.greenCF + (light ? "88" : "")
              : Colors.theme1.grayCC,
            backgroundColor: isAnswered
              ? Colors.theme1.greenFF + "22"
              : Colors.theme1.gray20 + "11",
            color: isAnswered
              ? light
                ? Colors.theme1.green79
                : Colors.theme1.greenCF
              : light
              ? Colors.theme1.gray20
              : Colors.theme1.white,
          }}
        >
          {isAnswered ? "پاسخ داده شده" : "بدون پاسخ"}
        </Text>
      </View>
    </Pressable>
  );
};

const mapStateToProps = (state) => ({
  theme: state.publicApi.theme,
  list: state.comment.myList,
});

const mapDispatchToProps = {
  getTicketList: comment.myList,
};

export default connect(mapStateToProps, mapDispatchToProps)(Tickets);
