import React from "react";
import {
  View,
  Text,
  Image,
  Pressable,
  FlatList,
  Platform,
  Linking,
  Dimensions,
} from "react-native";
import { connect } from "react-redux";
import { useNavigation } from "@react-navigation/native";

//components
import Progress from "../../../components/Progress";
import Modal from "../../../components/Modal";

//Color
import Colors from "../../../constants/Colors";
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";

const ios = Platform.OS === "ios";
const { width, height } = Dimensions.get("window");

function MyBooks({ books, grades, theme, mobile }) {
  return books?.filter(
    (book) =>
      (book?.productType === 2 || book?.productType === 3) &&
      book?.condition >= 2
  ).length ? (
    <View style={[tw("flex w-full mb-5")]}>
      <View
        style={[
          tw(`w-full flex  rounded-md pt-3 overflow-hidden`),
          {
            backgroundColor:
              theme === "light"
                ? Colors.theme1.greenCF + "0F"
                : Colors.theme1.greenCF + "11",
            borderColor:
              Colors.theme1.greenD9 + (theme === "light" ? "" : "77"),
            borderWidth: 1,
          },
        ]}
      >
        <Text
          style={[
            tw(`pr-4 ${ios ? "text-right" : ""} w-full`),
            {
              color:
                theme === "light" ? Colors.theme1.green79 : Colors.theme1.white,
              fontFamily: "DemiBold",
              fontSize: fontSize.lg,
            },
          ]}
        >
          کتابهای من
        </Text>
        <FlatList
          showsHorizontalScrollIndicator={false}
          style={[tw("py-3")]}
          horizontal={true}
          inverted={true}
          data={books?.filter((book) => book?.condition >= 2)}
          renderItem={({ item }) => (
            <Book book={item} grades={grades} theme={theme} mobile={mobile} />
          )}
          keyExtractor={(book) => book?.id}
        />
      </View>
    </View>
  ) : null;
}

const Book = ({ book, grades, theme, mobile }) => {
  const [openModal, setOpenModal] = React.useState(false);
  const navigation = useNavigation();

  const actions = {
    3: () =>
      Linking.openURL(`https://ar.dnvn.ir/lunch?id=${book?.product?.ARId}`),
    2: () =>
      Linking.openURL(`https://ar.dnvn.ir/lunch?id=${book?.product?.ARId}`),
    4: () => {},
  };
  return (
    <Pressable
      style={tw(`flex mr-4 ${ios ? "items-end" : ""}`)}
      onPress={() => setOpenModal(true)}
    >
      <View style={{ height: mobile ? 165 : height / 5 }}>
        <Image
          source={{
            uri: `https://dnvn.ir/api/v1/file/${book?.product?.book?.fileIds}`,
          }}
          resizeMode="contain"
          style={[
            {
              width: mobile ? 110 : ((height / 5) * 3) / 4,
              flex: 1,
            },
          ]}
        />
      </View>
      <Text
        style={[
          tw("mt-2 pr-1"),
          {
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            fontFamily: "Medium",
            fontSize: fontSize.tiny,
          },
        ]}
      >
        {book?.name}
      </Text>
      <Text
        style={[
          tw("pr-1"),
          {
            color:
              theme === "light" ? Colors.theme1.gray20 : Colors.theme1.white,
            fontFamily: "Light",
            fontSize: fontSize.sm,
          },
        ]}
      >
        {"پایه" + " " + grades[book?.product?.book?.gradeId]}
      </Text>
      <Progress percent={60} alignItems={"items-end"} />
      <Modal type="fade" openModal={openModal} setOpenModal={setOpenModal}>
        <Pressable
          style={[
            tw("flex-1 justify-center items-center relative"),
            {
              shadowColor: "#00000055",
              shadowOffset: { width: 0, height: 1 },
              shadowOpacity: 0.8,
              shadowRadius: 2,
              elevation: 5,
              backgroundColor: Colors.theme1.dark + "aa",
            },
          ]}
          onPress={() => setOpenModal(!openModal)}
        >
          <Pressable
            onPress={(e) => e.stopPropagation()}
            style={[
              tw("flex flex-col items-center p-4 rounded-md relative"),
              {
                backgroundColor:
                  theme === "light" ? Colors.theme1.white : Colors.theme1.dark,
              },
            ]}
          >
            {/* <AntDesign
              name="close"
              style={{
                backgroundColor:
                  theme === "light" ? Colors.theme1.white : Colors.theme1.dark,
                padding: 4,
                borderRadius: 200,
                position: "absolute",
                right: 8,
                top: mobile ? -20 : -30,
              }}
              size={mobile ? 20 : 30}
              color={Colors.theme1.redFF1}
              onPress={() => setOpenModal(!openModal)}
            /> */}
            <Image
              source={{
                uri: `https://dnvn.ir/api/v1/file/${book?.product?.book?.fileIds}`,
              }}
              resizeMode="contain"
              style={[
                tw("bg-gray-100 mb-3"),
                {
                  height: ((width / 2) * 4.25) / 3,
                  width: width / 2,
                },
              ]}
            />
            <View style={tw("flex items-center")}></View>
            <Pressable
              onPress={() => {
                setOpenModal(!openModal);
                navigation.push("QR", { page: "activation" });
              }}
              style={{
                backgroundColor: Colors.theme1.greenD9,
                color: "white",
                width: width / 2,
                paddingVertical: 10,
                borderRadius: 5,
              }}
            >
              <Text
                style={{
                  fontFamily: "Regular",
                  textAlign: "center",
                  color: Colors.theme1.white,
                  fontSize: fontSize.tiny,
                }}
              >
                QR اسکن کد
              </Text>
            </Pressable>
            <Pressable
              onPress={() => {
                setOpenModal(!openModal);
                Linking.openURL(
                  `https://ar.dnvn.ir/lunch?id=${book?.product?.ARId}`
                );
              }}
              style={{
                backgroundColor: Colors.theme1.gray2077,
                color: "white",
                width: width / 2,
                paddingVertical: 10,
                borderRadius: 5,
                marginTop: 12,
              }}
            >
              <Text
                style={{
                  fontFamily: "Regular",
                  textAlign: "center",
                  color: Colors.theme1.white,
                  fontSize: fontSize.tiny,
                }}
              >
                واقعیت افزوده
              </Text>
            </Pressable>
          </Pressable>
        </Pressable>
      </Modal>
    </Pressable>
  );
};

const mapStateToProps = (state) => ({
  grades: state.publicApi.grades,
  theme: state.publicApi.theme,
  mobile: state.publicApi.mobile,
});

export default connect(mapStateToProps)(MyBooks);
