import React from "react";
import { View, Text, Dimensions, Pressable } from "react-native";
import { Rating } from "react-native-ratings";
import { connect } from "react-redux";
import { vote } from "../../../redux/actions";
import { asyncAwesomeAlert } from "../../../utils/AsyncWrappers";

//assets
import tw from "tailwind-rn";
import fontSize from "../../../constants/fontSize";
import Colors from "../../../constants/Colors";

const width = Dimensions.get("window").width;

function Rates({ productId, addVote, isBuyed = null, theme, rateDetail }) {
  const fiveCount = React.useMemo(() => {
    return rateDetail?.filter((rate) => rate?.rate === 5)[0];
  }, [rateDetail]);

  const fourCount = React.useMemo(() => {
    return rateDetail?.filter((rate) => rate?.rate === 4)[0];
  }, [rateDetail]);

  const threeCount = React.useMemo(() => {
    return rateDetail?.filter((rate) => rate?.rate === 3)[0];
  }, [rateDetail]);

  const twoCount = React.useMemo(() => {
    return rateDetail?.filter((rate) => rate?.rate === 2)[0];
  }, [rateDetail]);

  const oneCount = React.useMemo(() => {
    return rateDetail?.filter((rate) => rate?.rate === 1)[0];
  }, [rateDetail]);

  const allCount = React.useMemo(() => {
    return rateDetail?.reduce((a, b) => a + b?.count, 0);
  }, [rateDetail]);

  const rate = React.useMemo(() => {
    return rateDetail?.length ? ((oneCount?.count || 0) * 1 +
      (twoCount?.count || 0) * 2 +
      (threeCount?.count || 0) * 3 +
      (fourCount?.count || 0) * 4 +
      (fiveCount?.count || 0) * 5) / rateDetail?.length : 0;
  }, [rateDetail]);

  return (
    <View style={tw("flex flex-row-reverse")}>
      <Pressable
        style={[tw("flex items-center justify-center"), { width: "25%" }]}
        onPress={() => {}}
      >
        <Text
          style={[
            {
              fontSize: fontSize.xl6,
              color: theme === "light" ? "#05335F" : Colors.theme1.white,
              fontFamily: "Medium",
            },
          ]}
        >
          {rate || 4}
        </Text>
        <Rating
          type="star"
          ratingCount={5}
          imageSize={width / 25}
          ratingColor={Colors.theme1.grayE3}
          tintColor={
            theme === "light" ? Colors.theme1.white : Colors.theme1.dark
          }
          startingValue={rate}
          onFinishRating={(rating) => addVote({ productId, vote: rating })}
          readonly={!isBuyed}
        />
        <Text
          style={{
            fontSize: fontSize.sm,
            color: theme === "light" ? "#707070" : Colors.theme1.white,
            fontFamily: "Light",
            marginTop: 5,
          }}
        >
          {`از بین ${allCount} نفر`}
        </Text>
      </Pressable>
      <View style={[tw("flex  flex-1"), { width: "60%" }]}>
        {[
          {
            name: "یک ستاره",
            value: ((oneCount?.count || 0) / allCount) * 100,
          },
          {
            name: "دو ستاره",
            value: ((twoCount?.count || 0) / allCount) * 100,
          },
          {
            name: "سه ستاره",
            value: ((threeCount?.count || 0) / allCount) * 100,
          },
          {
            name: "چهار ستاره",
            value: ((fourCount?.count || 0) / allCount) * 100,
          },
          {
            name: "پنج ستاره",
            value: ((fiveCount?.count || 0) / allCount) * 100,
          },
        ].map((field, index) => (
          <Progress key={index} data={field} theme={theme} />
        ))}
      </View>
    </View>
  );
}

const Progress = ({ data, theme, ...props }) => {
  return (
    <View style={[tw("flex flex-1 flex-row items-center py-1.5")]}>
      <Text
        style={{
          fontSize: fontSize.sm,
          color: theme === "light" ? "#05335F" : Colors.theme1.white,
          fontFamily: "Regular",
        }}
      >
        {data.name}
      </Text>
      <View
        style={[
          tw("rounded-md ml-2 flex-1"),
          { height: 6, backgroundColor: Colors.theme1.greenFF1 },
        ]}
      >
        <View
          style={[
            tw("h-full rounded-md"),
            {
              width: data.value + "%",
              backgroundColor: Colors.theme1.greenCF,
            },
          ]}
        ></View>
      </View>
      <Text
        style={{
          fontSize: fontSize.xs,
          fontFamily: "Light",
          width: width / 7.5,
          textAlign: "center",
          color: theme === "light" ? "#05335F" : Colors.theme1.white,
        }}
      >
        {data.value + "%"}
      </Text>
    </View>
  );
};

const mapStateToProps = (state) => ({
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  addVote: vote.add,
};

export default connect(mapStateToProps, mapDispatchToProps)(Rates);
