import {
  View,
  Text,
  Pressable,
  Image,
  Dimensions,
  Platform,
} from "react-native";
import React from "react";
import { connect } from "react-redux";
import { useNavigation } from "@react-navigation/native";

//style
import tw from "tailwind-rn";
import Colors from "../../../constants/Colors";
import fontSize from "../../../constants/fontSize";

const ios = Platform.OS === "ios";

const Main = ({ books, filterOptions, grades, mobile, theme, orientation }) => {
  const [width, setWidth] = React.useState(Dimensions.get("window").width);
  const navigation = useNavigation();
  const [filterLoading, setFilterLoading] = React.useState(false);

  React.useEffect(() => {
    setFilterLoading(() => true);
    setTimeout(() => {
      setFilterLoading(() => false);
    }, 500);
  }, [filterOptions]);

  const Items = (type) => {
    const { grade, subject, available, sort, productType, search } =
      filterOptions;
    let byGradeFilter;
    let bySubjectFilter;
    let byAvailableFilter;
    let bySearchFilter;
    if (grade && grade !== "همه پایه ها") {
      byGradeFilter = books?.filter((book) => grades[book?.gradeId] === grade);
    } else {
      byGradeFilter = books;
    }
    if (subject) {
      bySubjectFilter = byGradeFilter?.filter(
        (book) =>
          book?.product[type]?.name?.indexOf(subject) !== -1 ||
          book?.name?.indexOf(subject) !== -1
      );
    } else {
      bySubjectFilter = byGradeFilter;
    }
    if (available) {
      byAvailableFilter = bySubjectFilter?.filter(
        (book) => book?.product[type]?.price
      );
    } else {
      byAvailableFilter = bySubjectFilter;
    }
    if (search) {
      bySearchFilter = byAvailableFilter?.filter(
        (book) =>
          book?.product[type]?.name?.indexOf(search) !== -1 ||
          book?.name?.indexOf(search) !== -1
      );
    } else {
      bySearchFilter = byAvailableFilter;
    }

    return filterOptions?.productType === "محصولات ویدیویی"
      ? bySearchFilter?.map((product, index) => (
          <></>
          // <Pressable
          //   style={[
          //     {
          //       width: mobile ? "auto" : width / 2.2,
          //       borderWidth: 1,
          //       borderColor:
          //         Colors.theme1.grayE3 + (theme === "light" ? "" : "55"),
          //     },
          //     tw(`flex  mb-5 p-2 rounded-md ${mobile ? "w-full" : ""}`),
          //   ]}
          //   key={index}
          //   onPress={() => navigation.navigate("Video", { id: product.id })}
          // >
          //   <View style={[tw("relative w-full mb-1")]}>
          //     <Image
          //       source={{
          //         uri: `https://dnvn.ir/api/v1/file/${product?.fileIds}`,
          //       }}
          //       style={[
          //         tw("w-full rounded-sm"),
          //         { height: ((mobile ? width - 25 : width / 2.2) * 9) / 16 },
          //       ]}
          //     />
          //   </View>

          //   <Text
          //     style={[
          //       tw("mb-1"),
          //       {
          //         fontFamily: "Medium",
          //         fontSize: mobile ? fontSize.lg : fontSize.base,
          //         color:
          //           theme === "light"
          //             ? Colors.theme1.gray20
          //             : Colors.theme1.white,
          //         textAlign: ios ? "right" : "auto",
          //       },
          //     ]}
          //   >
          //     {"دوره ویدئویی" + " " + product?.name}
          //   </Text>
          //   <Text
          //     style={[
          //       tw("mb-4"),
          //       {
          //         fontSize: mobile ? fontSize.tiny : fontSize.sm,
          //         fontFamily: "Regular",
          //         color: Colors.theme1.greenBA,
          //         textAlign: ios ? "right" : "auto",
          //       },
          //     ]}
          //   >
          //     {"پایه" + " " + grades[product?.gradeId]}
          //   </Text>
          //   <Text
          //     style={[
          //       tw("w-full flex flex-row text-left"),
          //       {
          //         fontSize: mobile ? fontSize.xl : fontSize.lg,
          //         fontFamily: "Medium",
          //         color:
          //           theme === "light"
          //             ? Colors.theme1.gray20
          //             : Colors.theme1.white,
          //       },
          //     ]}
          //   >
          //     {separate(
          //       product?.product?.filter(
          //         (product) => product?.productType === 4
          //       )[0].price
          //     )}{" "}
          //     <Text style={{ fontSize: fontSize.sm }}>تومان</Text>
          //   </Text>
          // </Pressable>
        ))
      : bySearchFilter?.map((product, index) => (
          <React.Fragment key={index}>
            {(
              productType
                ? productType === ("محصولات دیجیتال" || "همه محصولات")
                : true
            ) ? (
              <Pressable
                key={product?.product[0]?.id}
                style={[
                  {
                    width: mobile
                      ? width / 2 - 25
                      : orientation === "portrait"
                      ? width / 4.2
                      : width / 5.2,
                    marginBottom: 15,
                    borderWidth: 1,
                    borderColor:
                      Colors.theme1.grayE3 + (theme === "light" ? "" : "55"),
                  },
                  tw("flex justify-between px-2 pt-2 rounded-md"),
                ]}
                onPress={() =>
                  navigation.navigate("Product", {
                    id: product?.id,
                    type: "book",
                  })
                }
              >
                <View style={tw("w-full flex pb-2")}>
                  <Image
                    resizeMode="contain"
                    source={{
                      uri: `https://dnvn.ir/api/v1/file/${product?.fileIds}`,
                    }}
                    style={[
                      tw("rounded-sm"),
                      {
                        flex: 1,
                        height: mobile
                          ? ((width / 2 - 25) * 4) / 2.9
                          : ((width / 3.2) * 16) / 16,
                      },
                    ]}
                  />
                  <Text
                    style={{
                      fontSize: mobile ? fontSize.base : fontSize.tiny,
                      marginTop: 5,
                      fontFamily: "Medium",
                      width: "100%",
                      textAlign: ios ? "right" : "auto",
                      color:
                        theme === "light"
                          ? Colors.theme1.gray20
                          : Colors.theme1.white,
                    }}
                  >
                    {product?.name}
                  </Text>
                  <Text
                    style={{
                      color: Colors.theme1.greenBA,
                      fontSize: mobile ? fontSize.tiny : fontSize.sm,
                      marginTop: 5,
                      fontFamily: "Regular",
                      width: "100%",
                      textAlign: ios ? "right" : "auto",
                    }}
                  >
                    {"پایه" + " " + grades[product?.gradeId]}
                  </Text>
                </View>
              </Pressable>
            ) : null}
          </React.Fragment>
        ));
  };

  return (
    <View
      onLayout={() => setWidth(Dimensions.get("window").width)}
      style={[
        tw(
          `flex w-full px-4 flex-wrap  justify-between ${
            ios ? "flex-row-reverse" : "flex-row"
          }`
        ),
      ]}
    >
      {filterOptions?.productType === "محصولات ویدیویی" ? Items(2) : null}
      {filterOptions?.productType === "محصولات دیجیتال" ? Items(0) : null}
      {filterOptions?.productType === "محصولات فیزیکی" ? Items(1) : null}
      {!filterOptions?.productType ? Items(0) : null}
      {/* {filterLoading && (
        <View style="w-full h-screen flex justify-center items-center bg-white bg-opacity-20 backdrop-filter backdrop-blur-xl fixed left-0 top-0">
          <Loading size={4} color="bg-green-400" />
        </View>
      )} */}
    </View>
  );
};

const mapStateToProps = (state) => ({
  filterOptions: state.book.filterOptions,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
  orientation: state.publicApi.orientation,
});

const mapDispatchToProps = {};

export default connect(mapStateToProps, mapDispatchToProps)(Main);
