import {
  View,
  Text,
  Pressable,
  TouchableOpacity,
  SafeAreaView,
  ScrollView,
  StyleSheet,
  Platform,
  Dimensions,
  StatusBar,
} from "react-native";
import React from "react";
import { connect } from "react-redux";
import { asyncAwesomeAlert } from "../../../../utils/AsyncWrappers";
import { useNavigation } from "@react-navigation/native";
import { userAddress, userFactor } from "../../../../redux/actions";

//components
import Navbar from "../../../../components/Navbar";
import Empty from "../../../../components/Empty";

//style
import tw from "tailwind-rn";
import Colors from "../../../../constants/Colors";
import fontSize from "../../../../constants/fontSize";

const ios = Platform.OS === "ios";
const { height, width } = Dimensions.get("window");

const ProfileAddress = ({
  addresses,
  update,
  getList,
  userId,
  userAddressId,
  getFactorInfo,
  mobile,
  loading,
  theme,
  deleteItem,
}) => {
  const navigation = useNavigation();
  const [height, setHeight] = React.useState(height);
  const Location = ({ address, active }) => {
    return (
      <Pressable
        style={[
          {
            backgroundColor:
              userAddressId === address?.id
                ? theme === "light"
                  ? Colors.theme1.greenCF + "0a"
                  : Colors.theme1.dark
                : theme === "light"
                ? Colors.theme1.grayE3 + "44"
                : Colors.theme1.dark,
            borderWidth: 2,
            borderColor:
              userAddressId === address?.id
                ? Colors.theme1.greenCF + "aa"
                : Colors.theme1.grayE3,
          },
          tw(
            `flex flex-row-reverse items-center w-full px-3 py-2 rounded-md mb-4`
          ),
        ]}
        onPress={() =>
          userAddressId === address?.id
            ? {}
            : update({ userAddressId: address?.id, userId })
        }
      >
        <View style={tw("flex flex-1  mr-2")}>
          {active ? (
            <View
              style={tw("w-full flex flex-row-reverse justify-between mb-3")}
            >
              <View style={tw("flex flex-row-reverse items-center")}>
                <Text
                  style={{
                    fontSize: fontSize.base,
                    fontFamily: "Medium",
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white,
                  }}
                >
                  آدرس انتخابی شما
                </Text>
                <Text
                  style={{
                    fontSize: fontSize.xs,
                    fontFamily: "Regular",
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white,
                    marginRight: 10,
                  }}
                >
                  فعال
                </Text>
              </View>
              <View style={tw("flex flex-row-reverse")}>
                <Pressable
                  style={tw("ml-4")}
                  onPress={() =>
                    navigation.navigate("CreateAddress", {
                      type: "editAddress",
                      form: address,
                    })
                  }
                >
                  <></>
                  {/* <Ionicons
                    name="ios-pencil-sharp"
                    size={20}
                    color={
                      theme === "light"
                        ? "#52796F"
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white
                    }
                  /> */}
                </Pressable>
                <Pressable
                  onPress={() =>
                    asyncAwesomeAlert("", "آدرس مورد نظر حذف شود؟", {
                      showCancelButton: true,
                      confirmText: "بله",
                      cancelText: "لغو",
                      onConfirm: () => deleteItem({ id: address?.id }),
                    })
                  }
                >
                  <></>
                  {/* <Ionicons
                    name="trash-bin"
                    size={20}
                    color={
                      theme === "light"
                        ? "#52796F"
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white
                    }
                  /> */}
                </Pressable>
              </View>
            </View>
          ) : null}
          <View style={tw(`flex w-full ${active ? "" : "flex-row-reverse"}`)}>
            <View style={tw("flex  flex-1 mb-4")}>
              <Text
                style={[
                  {
                    fontFamily: "Regular",
                    fontSize: mobile ? fontSize.sm : fontSize.tiny,
                    lineHeight: 22,
                    textAlign: ios ? "right" : "auto",
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white,
                  },
                ]}
              >
                {"آدرس:" + " " + address?.address}
              </Text>
              <Text
                style={[
                  {
                    marginTop: mobile ? 4 : 8,
                    fontFamily: "Regular",
                    fontSize: mobile ? fontSize.sm : fontSize.tiny,
                    lineHeight: 22,
                    textAlign: ios ? "right" : "auto",
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white,
                  },
                ]}
              >
                {"نام:" + " " + address?.firstName + " " + address?.lastName}
              </Text>
              <Text
                style={[
                  {
                    marginTop: mobile ? 4 : 8,
                    fontFamily: "Regular",
                    fontSize: mobile ? fontSize.sm : fontSize.tiny,
                    lineHeight: 22,
                    textAlign: ios ? "right" : "auto",
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white,
                  },
                ]}
              >
                {"کد پستی:" + " " + address?.postalCode}
              </Text>
              <Text
                style={[
                  {
                    marginTop: mobile ? 4 : 8,
                    fontFamily: "Regular",
                    fontSize: mobile ? fontSize.sm : fontSize.tiny,
                    lineHeight: 22,
                    textAlign: ios ? "right" : "auto",
                    color:
                      theme === "light"
                        ? Colors.theme1.gray20
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white,
                  },
                ]}
              >
                {"شماره تماس:" + " " + address?.cellphone}
              </Text>
            </View>
            {!active ? (
              <View style={tw("flex flex-row-reverse")}>
                <Pressable
                  style={tw("ml-4")}
                  onPress={() =>
                    navigation.navigate("CreateAddress", {
                      type: "editAddress",
                      form: address,
                    })
                  }
                >
                  <></>
                  {/* <Ionicons
                    name="ios-pencil-sharp"
                    size={20}
                    color={
                      theme === "light"
                        ? "#52796F"
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white
                    }
                  /> */}
                </Pressable>
                <Pressable
                  onPress={() =>
                    asyncAwesomeAlert("", "آدرس مورد نظر حذف شود؟", {
                      showCancelButton: true,
                      confirmText: "بله",
                      cancelText: "لغو",
                      onConfirm: () => deleteItem({ id: address?.id }),
                    })
                  }
                >
                  <Ionicons
                    name="trash-bin"
                    size={20}
                    color={
                      theme === "light"
                        ? "#52796F"
                        : active
                        ? Colors.theme1.greenCF
                        : Colors.theme1.white
                    }
                  />
                </Pressable>
              </View>
            ) : null}
          </View>

          {/* <CustomPressable
            title={"مشاهده روی نقشه"}
            backgroundColor={
              active
                ? Colors.theme1.greenCF
                : Colors.theme1.gray20 + "66"
            }
            color={"white"}
            border={{ color: "#196EC0", width: 0 }}
            width={"100%"}
            onPress={() => {}}
          /> */}
        </View>
      </Pressable>
    );
  };

  React.useEffect(() => {
    getFactorInfo({ userId });
    getList();
  }, []);

  return (
    <SafeAreaView
      style={{
        paddingTop: Platform.OS === "android" ? StatusBar.currentHeight : 0,
        position: "relative",
        flex: 1,
        paddingBottom : 20
      }}
    >
      <Navbar
        headerOptions={{
          logo: false,
          menu: false,
          hamburgerMenu: false,
          title: "آدرس‌ها",
          bookmark: false,
          qr: false,
          back: true,
        }}
      />
      {addresses?.length ? (
        <ScrollView
          contentContainerStyle={styles.contentContainerStyle}
          style={[styles.container]}
          onLayout={() => setHeight(Dimensions.get("window").height)}
        >
          <View style={tw("w-full mt-2 px-4")}>
            <View style={tw("p-0 m-0 flex ")}>
              {addresses?.map((address, index) => (
                <Location
                  address={address}
                  key={index}
                  active={userAddressId === address?.id}
                />
              ))}
            </View>
          </View>
        </ScrollView>
      ) : (
        <Empty text="هیچ آدرسی ثبت نشده" />
      )}
      <View style={tw("w-full px-4")}>
        <TouchableOpacity
          style={[
            {
              backgroundColor: Colors.theme1.greenCF + "05",
              borderColor: Colors.theme1.greenCF,
              borderWidth: 1.5,
            },
            tw(
              `flex flex-row-reverse self-end justify-center py-2 rounded-md items-center mt-4 w-full`
            ),
          ]}
          onPress={() => navigation.push("CreateAddress")}
        >
          <Text
            style={{
              fontFamily: "Medium",
              fontSize: fontSize.tiny,
              color: Colors.theme1.greenCF,
            }}
          >
            یک آدرس جدید اضافه کنید
          </Text>
          <Text
            style={{
              marginTop: 3,
              marginRight: 5,
              fontSize: fontSize.xl3,
              color: Colors.theme1.greenCF,
              fontFamily: "Medium",
            }}
          >
            +
          </Text>
        </TouchableOpacity>
      </View>
    </SafeAreaView>
  );
};

const mapStateToProps = (state) => ({
  userId: state.user.status?.id,
  userAddressId: state.userFactor.info?.userAddressId,
  loading: state.userFactor.loading,
  addresses: state.userAddress.list,
  mobile: state.publicApi.mobile,
  theme: state.publicApi.theme,
});

const mapDispatchToProps = {
  getFactorInfo: userFactor.info,
  update: userFactor.update,
  getList: userAddress.list,
  deleteItem: userAddress.del,
};

export default connect(mapStateToProps, mapDispatchToProps)(ProfileAddress);

const styles = StyleSheet.create({
  contentContainerStyle: {
    paddingBottom: 100,
    position: "relative",
  },
  container: {
    flexDirection: "column",
    paddingVertical: 0,
    paddingHorizontal: 0,
  },
});
